## Automation
  - Autodeploy on PyPi when merging into master (CI task)
  - Autogenerate ReadTheDocs when merging to master (ReadTheDocs merge listener)
  - Set commit tag when merging into master (CI task)
  - Automatize step "Set this version number" of the release process when creating a new version branch

## Documentation 
  - Create proper sections: https://realpython.com/documenting-python-code/#public-and-open-source-projects
